@@ -15,7 +15,7 @@
 #   limitations under the License.
 
 EXISTDB_SERVER_PROTOCOL = "http://"
-EXISTDB_SERVER_HOST     = "localhost:8080/exist"
+EXISTDB_SERVER_HOST     = "kamina.library.emory.edu:8080/exist"
 # NOTE: test account used for tests that require non-guest access; user should be in eXist DBA group
 EXISTDB_DBA_USER     = "username"
 EXISTDB_DBA_PASSWORD = "pwd"
